﻿/*

### .ai 파일을 .pdf 로 변환하는 법 

1. 파라미터 만들기 : 사용자 Temporary 폴더("C:\Users\<UserID>\AppData\Local\Temp\")에 "ai2pdf.arg" 파일을 만든다.
    - 첫번째 라인은 원본 .ai 파일 경로
    - 두번째 라인은 변환할 .pdf 파일 경로
    - 세번째 라인은 변환할때 적용할 preset 이름 (없으면 디폴트 적용)

    예) 
    C:\Work\taekukgi.ai
    C:\Work\taekukgi.pdf
    MyPDFPreset


2. 스크립트 실행파일 경로 : JSX 파일의 경로는 기본적으로 PrintBe 익스텐션내의 ~/jsx/ai2pdf.jsx 이다.

    예) 
    "C:\Program Files (x86)\Common Files\Adobe\CEP\extensions\com.printbe.smartform\jsx\ai2pdf.jsx"



3. 실행하기 : 다음과 같은 형식의 명령을 실행한다.

    다음)
	
    C:\>"일러스트레이터 실행파일 경로" -run "jsx파일 경로"

	예)
	"C:\Program Files\Adobe\Adobe Illustrator CC 2017\Support Files\Contents\Windows\Illustrator.exe" -run "C:\Program Files (x86)\Common Files\Adobe\CEP\extensions\com.printbe.smartform\jsx\ai2pdf.jsx"
	

	
	*/




function cvtAI2PDF(){
	var temp_folder = Folder.temp;
	var arg_file = new File(temp_folder+"/ai2pdf.arg");
	arg_file.open("r");
	var paths_str = arg_file.read();
	arg_file.close();

	var paths = paths_str.split("\n");
	if(paths.length < 2)
		return;
	
	var preset_name = null;
	if(paths.length > 2 && paths[2].length > 0) {
		preset_name = paths[2];
	}

	var src_ai = paths[0];
	var tar_pdf = paths[1];
	var src_ai_file = new File(src_ai);
	var tar_pdf_file = new File(tar_pdf);
	var doc = app.open(src_ai_file);
	var pdf_opt = new PDFSaveOptions();
	if(preset_name) {
		var i, icnt = app.PDFPresetsList.length;
		for(i=0;i<icnt;i++) {
			var preset = app.PDFPresetsList[i];
			if(preset == preset_name) {
				pdf_opt.pDFPreset = preset;
				break;
			}
		}
	}
	doc.saveAs(tar_pdf_file, pdf_opt);
	doc.close(SaveOptions.DONOTSAVECHANGES);
}

cvtAI2PDF();
